@@ -49,6 +49,7 @@ TODO:
       background: no-repeat left url()  #fff
       -> background: #fff url() no-repeat left
 """
+
 __all__ = ['CSSStyleDeclaration', 'Property']
 
 from .cssproperties import CSS2Properties
@@ -106,7 +107,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             a flag defining if this sheet should be validated on change.
             Defaults to None, which means defer to the parent stylesheet.
         """
-        super(CSSStyleDeclaration, self).__init__()
+        super().__init__()
         self._parentRule = parentRule
         self.validating = validating
         self.cssText = cssText
@@ -192,7 +193,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         ]
         known.extend(CSS2Properties._properties)
         if n in known:
-            super(CSSStyleDeclaration, self).__setattr__(n, v)
+            super().__setattr__(n, v)
         else:
             raise AttributeError(
                 'Unknown CSS Property, '
@@ -201,13 +202,13 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             )
 
     def __repr__(self):
-        return "cssutils.css.%s(cssText=%r)" % (
+        return "cssutils.css.{}(cssText={!r})".format(
             self.__class__.__name__,
             self.getCssText(separator=' '),
         )
 
     def __str__(self):
-        return "<cssutils.css.%s object length=%r (all: %r) at 0x%x>" % (
+        return "<cssutils.css.{} object length={!r} (all: {!r}) at 0x{:x}>".format(
             self.__class__.__name__,
             self.length,
             len(self.getProperties(all=True)),
@@ -501,7 +502,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
         else:
             return None
 
-    def getPropertyValue(self, name, normalize=True):
+    def getPropertyValue(self, name, normalize=True, default=''):
         r"""
         :param name:
             of the CSS property, always lowercase (even if not normalized)
@@ -511,16 +512,18 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
 
             If ``False`` may return **NOT** the effective value but the
             effective for the unnormalized name.
+        :param default:
+            value to be returned if the property has not been set.
         :returns:
             the value of the effective property if it has been explicitly set
-            for this declaration block. Returns the empty string if the
+            for this declaration block. Returns `default` if the
             property has not been set.
         """
         p = self.getProperty(name, normalize)
         if p:
             return p.value
         else:
-            return ''
+            return default
 
     def getPropertyPriority(self, name, normalize=True):
         r"""
@@ -666,7 +669,7 @@ class CSSStyleDeclaration(CSS2Properties, cssutils.util.Base2):
             self.seq._readonly = True
 
         else:
-            self._log.warn('Invalid Property: %s: %s %s' % (name, value, priority))
+            self._log.warn(f'Invalid Property: {name}: {value} {priority}')
 
     def item(self, index):
         """(DOM) Retrieve the properties that have been explicitly set in
