@@ -1,6 +1,5 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """cssutils serializer"""
+
 __all__ = ['CSSSerializer', 'Preferences']
 
 from cssutils.helper import normalize
@@ -28,7 +27,7 @@ def _escapecss(e):
 codecs.register_error('escapecss', _escapecss)
 
 
-class Preferences(object):
+class Preferences:
     r"""Control output of CSSSerializer.
 
     defaultAtKeyword = True
@@ -117,17 +116,17 @@ class Preferences(object):
                 self.__setattr__(key, value)
 
     def __repr__(self):
-        return "cssutils.css.%s(%s)" % (
+        return "cssutils.css.{}({})".format(
             self.__class__.__name__,
-            ', '.join(
-                ['\n    %s=%r' % (p, self.__getattribute__(p)) for p in self.__dict__]
-            ),
+            ', '.join([
+                f'\n    {p}={self.__getattribute__(p)!r}' for p in self.__dict__
+            ]),
         )
 
     def __str__(self):
-        return "<cssutils.css.%s object %s at 0x%x" % (
+        return "<cssutils.css.{} object {} at 0x{:x}".format(
             self.__class__.__name__,
-            ' '.join(['%s=%r' % (p, self.__getattribute__(p)) for p in self.__dict__]),
+            ' '.join([f'{p}={self.__getattribute__(p)!r}' for p in self.__dict__]),
             id(self),
         )
 
@@ -184,7 +183,7 @@ class Preferences(object):
         self.validOnly = False
 
 
-class Out(object):
+class Out:
     """A simple class which makes appended items available as a combined string"""
 
     def __init__(self, ser):
@@ -305,7 +304,7 @@ class Out(object):
         return delim.join(self.out)
 
 
-class CSSSerializer(object):
+class CSSSerializer:
     """Serialize a CSSStylesheet and its parts.
 
     To use your own serializing method the easiest is to subclass CSS
@@ -340,12 +339,10 @@ class CSSSerializer(object):
         """
         if not self.prefs.lineSeparator:
             return text
-        return self.prefs.lineSeparator.join(
-            [
-                '%s%s' % (level * self.prefs.indent, line)
-                for line in text.split(self.prefs.lineSeparator)
-            ]
-        )
+        return self.prefs.lineSeparator.join([
+            f'{level * self.prefs.indent}{line}'
+            for line in text.split(self.prefs.lineSeparator)
+        ])
 
     def _propertyname(self, property, actual):
         """
@@ -378,7 +375,7 @@ class CSSSerializer(object):
             and val[3] == val[4]
             and val[5] == val[6]
         ):
-            return '#%s%s%s' % (val[1], val[3], val[5])
+            return f'#{val[1]}{val[3]}{val[5]}'
         return val
 
     def _valid(self, x):
@@ -454,7 +451,7 @@ class CSSSerializer(object):
                 # assume comments {
                 out.append(item.value, item.type)
             out.append('{')
-            out.append('%s%s}' % (variablesText, self.prefs.lineSeparator), indent=1)
+            out.append(f'{variablesText}{self.prefs.lineSeparator}}}', indent=1)
             return out.value()
         else:
             return ''
@@ -477,7 +474,7 @@ class CSSSerializer(object):
                 # assume comments {
                 out.append(item.value, item.type)
             out.append('{')
-            out.append('%s%s}' % (styleText, self.prefs.lineSeparator), indent=1)
+            out.append(f'{styleText}{self.prefs.lineSeparator}}}', indent=1)
             return out.value()
         else:
             return ''
@@ -639,7 +636,7 @@ class CSSSerializer(object):
 
             if styleText:
                 if not rulesText:
-                    out.append('%s%s' % (styleText, self.prefs.lineSeparator), indent=1)
+                    out.append(f'{styleText}{self.prefs.lineSeparator}', indent=1)
                 else:
                     out.append(styleText, type_='styletext', indent=1, space=False)
 
@@ -761,10 +758,10 @@ class CSSSerializer(object):
         # TODO: sort selectors!
         if self.prefs.indentSpecificities:
             # subselectorlist?
-            elements = set([s.element for s in rule.selectorList])
+            elements = {s.element for s in rule.selectorList}
             specitivities = [s.specificity for s in rule.selectorList]
             for selector in self._selectors:
-                lastelements = set([s.element for s in selector])
+                lastelements = {s.element for s in selector}
                 if elements.issubset(lastelements):
                     # higher specificity?
                     lastspecitivities = [s.specificity for s in selector]
@@ -791,7 +788,7 @@ class CSSSerializer(object):
             self._level -= 1
         if not styleText:
             if self.prefs.keepEmptyRules:
-                return '%s%s{}' % (selectorText, self.prefs.paranthesisSpacer)
+                return f'{selectorText}{self.prefs.paranthesisSpacer}{{}}'
         else:
             return self._indentblock(
                 '%s%s{%s%s%s%s}'
@@ -857,7 +854,7 @@ class CSSSerializer(object):
                             except IndexError:
                                 prefix = ''
 
-                        out.append('%s|%s' % (prefix, name), type_, space=False)
+                        out.append(f'{prefix}|{name}', type_, space=False)
                 else:
                     out.append(val, type_, space=False, keepS=True)
 
@@ -1082,7 +1079,6 @@ class CSSSerializer(object):
                     else:
                         val = v[1:]
                 else:
-
                     val = self._strip_zeros('%f' % value.value)  # issue #27
 
                 # keep '+' if given
