@@ -1,6 +1,5 @@
 """Testcases for cssutils.css.CSSValue and CSSPrimitiveValue."""
 
-
 import xml.dom
 from . import basetest
 import cssutils
@@ -12,7 +11,7 @@ pytestmark = pytest.mark.xfail(reason="incomplete")
 
 
 class TestCSSValue(basetest.BaseTestCase):
-    def setup(self):
+    def setup_method(self):
         self.r = cssutils.css.CSSValue()  # needed for tests
 
     def test_init(self):
@@ -181,15 +180,11 @@ y"''': '''"xy"''',
             'u\\rl(a)': 'url(a)',
             'url("a")': 'url(a)',
             'url(  "a"  )': 'url(a)',
-            'url(a)': 'url(a)',
             'url(";")': 'url(";")',
             'url(",")': 'url(",")',
             'url(")")': 'url(")")',
             '''url("'")''': '''url("'")''',
             '''url('"')''': '''url("\\"")''',
-            '''url("'")''': '''url("'")''',
-            # operator
-            '1': '1',
             '1 2': '1 2',
             '1   2': '1 2',
             '1,2': '1, 2',
