@@ -4,34 +4,38 @@ import xml.dom
 import xml.dom.minidom
 import warnings
 
+import pytest
+
 import cssutils
 
 
-class TestDOMImplementation:
-    def setup_method(self):
-        self.domimpl = cssutils.DOMImplementationCSS()
+@pytest.fixture
+def domimpl():
+    return cssutils.DOMImplementationCSS()
 
-    def test_createCSSStyleSheet(self):
+
+class TestDOMImplementation:
+    def test_createCSSStyleSheet(self, domimpl):
         "DOMImplementationCSS.createCSSStyleSheet()"
         title, media = 'Test Title', cssutils.stylesheets.MediaList('all')
         with warnings.catch_warnings():
             warnings.simplefilter('ignore')
-            sheet = self.domimpl.createCSSStyleSheet(title, media)
+            sheet = domimpl.createCSSStyleSheet(title, media)
         assert isinstance(sheet, cssutils.css.CSSStyleSheet)
         assert title == sheet.title
         assert media == sheet.media
 
-    def test_createDocument(self):
+    def test_createDocument(self, domimpl):
         "DOMImplementationCSS.createDocument()"
-        doc = self.domimpl.createDocument(None, None, None)
+        doc = domimpl.createDocument(None, None, None)
         assert isinstance(doc, xml.dom.minidom.Document)
 
-    def test_createDocumentType(self):
+    def test_createDocumentType(self, domimpl):
         "DOMImplementationCSS.createDocumentType()"
-        doctype = self.domimpl.createDocumentType('foo', 'bar', 'raboof')
+        doctype = domimpl.createDocumentType('foo', 'bar', 'raboof')
         assert isinstance(doctype, xml.dom.minidom.DocumentType)
 
-    def test_hasFeature(self):
+    def test_hasFeature(self, domimpl):
         "DOMImplementationCSS.hasFeature()"
         tests = [
             ('css', '1.0'),
@@ -40,4 +44,4 @@ class TestDOMImplementation:
             ('stylesheets', '2.0'),
         ]
         for name, version in tests:
-            assert self.domimpl.hasFeature(name, version)
+            assert domimpl.hasFeature(name, version)
