@@ -4,27 +4,24 @@ import logging
 import io
 import sys
 import xml.dom
-import socket
+
+import pytest
 
 import cssutils
 
 
+@pytest.fixture(autouse=True)
+def save_log(monkeypatch):
+    """
+    Replace default log and ignore its output.
+    """
+    monkeypatch.setattr(cssutils.log, 'raiseExceptions', False)
+    monkeypatch.setattr(
+        cssutils.log, '_log', logging.getLogger('IGNORED-CSSUTILS-TEST')
+    )
+
+
 class TestErrorHandler:
-    def setup_method(self):
-        "replace default log and ignore its output"
-        self._oldlog = cssutils.log._log
-        self._saved = cssutils.log.raiseExceptions
-
-        cssutils.log.raiseExceptions = False
-        cssutils.log.setLog(logging.getLogger('IGNORED-CSSUTILS-TEST'))
-
-    def teardown_method(self):
-        "reset default log"
-        cssutils.log.setLog(self._oldlog)
-        # for tests only
-        cssutils.log.setLevel(logging.FATAL)
-        cssutils.log.raiseExceptions = self._saved
-
     def _setHandler(self):
         "sets new handler and returns StringIO instance to getvalue"
         s = io.StringIO()
@@ -91,6 +88,7 @@ class TestErrorHandler:
 
         cssutils.log.raiseExceptions = o
 
+    @pytest.mark.network
     def test_handlers(self):
         "cssutils.log"
         s = self._setHandler()
@@ -115,12 +113,6 @@ class TestErrorHandler:
 
         s = self._setHandler()
 
-        try:
-            socket.getaddrinfo('example.com', 80)
-        except OSError:
-            # skip the test as the name can't resolve
-            return
-
         cssutils.log.setLevel(logging.ERROR)
         cssutils.parseUrl('http://example.com')
         assert s.getvalue()[:38] == 'ERROR    Expected "text/css" mime type'
