@@ -1,54 +1,49 @@
 """Testcases for cssutils.util"""
 
-
-import cgi
+from email.message import Message
 import re
 import urllib.request
 import urllib.error
 import urllib.parse
-
-try:
-    import mock
-except ImportError:
-    mock = None
-    print("install mock library to run all tests")
-
-from . import basetest
+from unittest import mock
 
 from cssutils.util import Base, ListSeq, _readUrl, _defaultFetcher, LazyRegex
+import pytest
 
 
-class ListSeqTestCase(basetest.BaseTestCase):
+class TestListSeq:
     def test_all(self):
         "util.ListSeq"
         ls = ListSeq()
-        self.assertEqual(0, len(ls))
+        assert 0 == len(ls)
         # append()
-        self.assertRaises(NotImplementedError, ls.append, 1)
+        with pytest.raises(NotImplementedError):
+            ls.append(1)
         # set
-        self.assertRaises(NotImplementedError, ls.__setitem__, 0, 1)
+        with pytest.raises(NotImplementedError):
+            ls.__setitem__(0, 1)
 
         # hack:
         ls.seq.append(1)
         ls.seq.append(2)
 
         # len
-        self.assertEqual(2, len(ls))
+        assert 2 == len(ls)
         # __contains__
-        self.assertEqual(True, 1 in ls)
+        assert True is (1 in ls)
         # get
-        self.assertEqual(1, ls[0])
-        self.assertEqual(2, ls[1])
+        assert 1 == ls[0]
+        assert 2 == ls[1]
         # del
         del ls[0]
-        self.assertEqual(1, len(ls))
-        self.assertEqual(False, 1 in ls)
+        assert 1 == len(ls)
+        assert False is (1 in ls)
         # for in
         for x in ls:
-            self.assertEqual(2, x)
+            assert 2 == x
 
 
-class BaseTestCase(basetest.BaseTestCase):
+class TestBase:
     def test_normalize(self):
         "Base._normalize()"
         b = Base()
@@ -60,9 +55,9 @@ class BaseTestCase(basetest.BaseTestCase):
             # the tokenizer...
         }
         for test, exp in list(tests.items()):
-            self.assertEqual(b._normalize(test), exp)
+            assert b._normalize(test) == exp
             # static too
-            self.assertEqual(Base._normalize(test), exp)
+            assert Base._normalize(test) == exp
 
     def test_tokenupto(self):  # noqa: C901
         "Base._tokensupto2()"
@@ -145,10 +140,10 @@ class BaseTestCase(basetest.BaseTestCase):
                 restokens = b._tokensupto2(tokens, ('CHAR', '[', 0, 0))
 
             res = ''.join([t[1] for t in restokens])
-            self.assertEqual(exp, res)
+            assert exp == res
 
 
-class _readUrl_TestCase(basetest.BaseTestCase):
+class Test_readUrl:
     """needs mock"""
 
     def test_readUrl(self):
@@ -167,30 +162,30 @@ class _readUrl_TestCase(basetest.BaseTestCase):
             # defaultFetcher returns: readUrl returns
             None: (None, None, None),
             (None, ''): ('utf-8', 5, ''),
-            (None, '€'.encode('utf-8')): ('utf-8', 5, '€'),
-            ('utf-8', '€'.encode('utf-8')): ('utf-8', 1, '€'),
+            (None, '€'.encode()): ('utf-8', 5, '€'),
+            ('utf-8', '€'.encode()): ('utf-8', 1, '€'),
             ('ISO-8859-1', 'ä'.encode('iso-8859-1')): ('ISO-8859-1', 1, 'ä'),
-            ('ASCII', 'a'.encode('ascii')): ('ASCII', 1, 'a'),
+            ('ASCII', b'a'): ('ASCII', 1, 'a'),
         }
 
         for r, exp in list(tests.items()):
-            self.assertEqual(_readUrl(url, fetcher=make_fetcher(r)), exp)
+            assert _readUrl(url, fetcher=make_fetcher(r)) == exp
 
         tests = {
             # (overrideEncoding, parentEncoding, (httpencoding, content)):
             #                        readUrl returns
             # ===== 0. OVERRIDE WINS =====
             # override + parent + http
-            ('latin1', 'ascii', ('utf-16', ''.encode())): ('latin1', 0, ''),
-            ('latin1', 'ascii', ('utf-16', '123'.encode())): ('latin1', 0, '123'),
+            ('latin1', 'ascii', ('utf-16', b'')): ('latin1', 0, ''),
+            ('latin1', 'ascii', ('utf-16', b'123')): ('latin1', 0, '123'),
             ('latin1', 'ascii', ('utf-16', 'ä'.encode('iso-8859-1'))): (
                 'latin1',
                 0,
                 'ä',
             ),
-            ('latin1', 'ascii', ('utf-16', 'a'.encode('ascii'))): ('latin1', 0, 'a'),
+            ('latin1', 'ascii', ('utf-16', b'a')): ('latin1', 0, 'a'),
             # + @charset
-            ('latin1', 'ascii', ('utf-16', '@charset "ascii";'.encode())): (
+            ('latin1', 'ascii', ('utf-16', b'@charset "ascii";')): (
                 'latin1',
                 0,
                 '@charset "latin1";',
@@ -200,19 +195,19 @@ class _readUrl_TestCase(basetest.BaseTestCase):
                 0,
                 '@charset "latin1";ä',
             ),
-            ('latin1', 'ascii', ('utf-16', '@charset "utf-8";ä'.encode('utf-8'))): (
+            ('latin1', 'ascii', ('utf-16', '@charset "utf-8";ä'.encode())): (
                 'latin1',
                 0,
                 '@charset "latin1";\xc3\xa4',
             ),  # read as latin1!
             # override only
             ('latin1', None, None): (None, None, None),
-            ('latin1', None, (None, ''.encode())): ('latin1', 0, ''),
-            ('latin1', None, (None, '123'.encode())): ('latin1', 0, '123'),
+            ('latin1', None, (None, b'')): ('latin1', 0, ''),
+            ('latin1', None, (None, b'123')): ('latin1', 0, '123'),
             ('latin1', None, (None, 'ä'.encode('iso-8859-1'))): ('latin1', 0, 'ä'),
-            ('latin1', None, (None, 'a'.encode('ascii'))): ('latin1', 0, 'a'),
+            ('latin1', None, (None, b'a')): ('latin1', 0, 'a'),
             # + @charset
-            ('latin1', None, (None, '@charset "ascii";'.encode())): (
+            ('latin1', None, (None, b'@charset "ascii";')): (
                 'latin1',
                 0,
                 '@charset "latin1";',
@@ -222,19 +217,19 @@ class _readUrl_TestCase(basetest.BaseTestCase):
                 0,
                 '@charset "latin1";ä',
             ),
-            ('latin1', None, (None, '@charset "utf-8";ä'.encode('utf-8'))): (
+            ('latin1', None, (None, '@charset "utf-8";ä'.encode())): (
                 'latin1',
                 0,
                 '@charset "latin1";\xc3\xa4',
             ),  # read as latin1!
             # override + parent
             ('latin1', 'ascii', None): (None, None, None),
-            ('latin1', 'ascii', (None, ''.encode())): ('latin1', 0, ''),
-            ('latin1', 'ascii', (None, '123'.encode())): ('latin1', 0, '123'),
+            ('latin1', 'ascii', (None, b'')): ('latin1', 0, ''),
+            ('latin1', 'ascii', (None, b'123')): ('latin1', 0, '123'),
             ('latin1', 'ascii', (None, 'ä'.encode('iso-8859-1'))): ('latin1', 0, 'ä'),
-            ('latin1', 'ascii', (None, 'a'.encode('ascii'))): ('latin1', 0, 'a'),
+            ('latin1', 'ascii', (None, b'a')): ('latin1', 0, 'a'),
             # + @charset
-            ('latin1', 'ascii', (None, '@charset "ascii";'.encode())): (
+            ('latin1', 'ascii', (None, b'@charset "ascii";')): (
                 'latin1',
                 0,
                 '@charset "latin1";',
@@ -244,18 +239,18 @@ class _readUrl_TestCase(basetest.BaseTestCase):
                 0,
                 '@charset "latin1";ä',
             ),
-            ('latin1', 'ascii', (None, '@charset "utf-8";ä'.encode('utf-8'))): (
+            ('latin1', 'ascii', (None, '@charset "utf-8";ä'.encode())): (
                 'latin1',
                 0,
                 '@charset "latin1";\xc3\xa4',
             ),  # read as latin1!
             # override + http
-            ('latin1', None, ('utf-16', ''.encode())): ('latin1', 0, ''),
-            ('latin1', None, ('utf-16', '123'.encode())): ('latin1', 0, '123'),
+            ('latin1', None, ('utf-16', b'')): ('latin1', 0, ''),
+            ('latin1', None, ('utf-16', b'123')): ('latin1', 0, '123'),
             ('latin1', None, ('utf-16', 'ä'.encode('iso-8859-1'))): ('latin1', 0, 'ä'),
-            ('latin1', None, ('utf-16', 'a'.encode('ascii'))): ('latin1', 0, 'a'),
+            ('latin1', None, ('utf-16', b'a')): ('latin1', 0, 'a'),
             # + @charset
-            ('latin1', None, ('utf-16', '@charset "ascii";'.encode())): (
+            ('latin1', None, ('utf-16', b'@charset "ascii";')): (
                 'latin1',
                 0,
                 '@charset "latin1";',
@@ -265,34 +260,18 @@ class _readUrl_TestCase(basetest.BaseTestCase):
                 0,
                 '@charset "latin1";ä',
             ),
-            ('latin1', None, ('utf-16', '@charset "utf-8";ä'.encode('utf-8'))): (
-                'latin1',
-                0,
-                '@charset "latin1";\xc3\xa4',
-            ),  # read as latin1!
-            # override ü @charset
-            ('latin1', None, (None, '@charset "ascii";'.encode())): (
-                'latin1',
-                0,
-                '@charset "latin1";',
-            ),
-            ('latin1', None, (None, '@charset "utf-8";ä'.encode('latin1'))): (
-                'latin1',
-                0,
-                '@charset "latin1";ä',
-            ),
-            ('latin1', None, (None, '@charset "utf-8";ä'.encode('utf-8'))): (
+            ('latin1', None, ('utf-16', '@charset "utf-8";ä'.encode())): (
                 'latin1',
                 0,
                 '@charset "latin1";\xc3\xa4',
             ),  # read as latin1!
             # ===== 1. HTTP WINS =====
-            (None, 'ascii', ('latin1', ''.encode())): ('latin1', 1, ''),
-            (None, 'ascii', ('latin1', '123'.encode())): ('latin1', 1, '123'),
+            (None, 'ascii', ('latin1', b'')): ('latin1', 1, ''),
+            (None, 'ascii', ('latin1', b'123')): ('latin1', 1, '123'),
             (None, 'ascii', ('latin1', 'ä'.encode('iso-8859-1'))): ('latin1', 1, 'ä'),
-            (None, 'ascii', ('latin1', 'a'.encode('ascii'))): ('latin1', 1, 'a'),
+            (None, 'ascii', ('latin1', b'a')): ('latin1', 1, 'a'),
             # + @charset
-            (None, 'ascii', ('latin1', '@charset "ascii";'.encode())): (
+            (None, 'ascii', ('latin1', b'@charset "ascii";')): (
                 'latin1',
                 1,
                 '@charset "latin1";',
@@ -302,13 +281,13 @@ class _readUrl_TestCase(basetest.BaseTestCase):
                 1,
                 '@charset "latin1";ä',
             ),
-            (None, 'ascii', ('latin1', '@charset "utf-8";ä'.encode('utf-8'))): (
+            (None, 'ascii', ('latin1', '@charset "utf-8";ä'.encode())): (
                 'latin1',
                 1,
                 '@charset "latin1";\xc3\xa4',
             ),  # read as latin1!
             # ===== 2. @charset WINS =====
-            (None, 'ascii', (None, '@charset "latin1";'.encode())): (
+            (None, 'ascii', (None, b'@charset "latin1";')): (
                 'latin1',
                 2,
                 '@charset "latin1";',
@@ -318,7 +297,7 @@ class _readUrl_TestCase(basetest.BaseTestCase):
                 2,
                 '@charset "latin1";ä',
             ),
-            (None, 'ascii', (None, '@charset "latin1";ä'.encode('utf-8'))): (
+            (None, 'ascii', (None, '@charset "latin1";ä'.encode())): (
                 'latin1',
                 2,
                 '@charset "latin1";\xc3\xa4',
@@ -340,20 +319,20 @@ class _readUrl_TestCase(basetest.BaseTestCase):
                 '@charset "utf-8";\xe4',
             ),  # read as latin1!
             # ===== 4. parentEncoding WINS =====
-            (None, 'latin1', (None, ''.encode())): ('latin1', 4, ''),
-            (None, 'latin1', (None, '123'.encode())): ('latin1', 4, '123'),
+            (None, 'latin1', (None, b'')): ('latin1', 4, ''),
+            (None, 'latin1', (None, b'123')): ('latin1', 4, '123'),
             (None, 'latin1', (None, 'ä'.encode('iso-8859-1'))): ('latin1', 4, 'ä'),
-            (None, 'latin1', (None, 'a'.encode('ascii'))): ('latin1', 4, 'a'),
-            (None, 'latin1', (None, 'ä'.encode('utf-8'))): (
+            (None, 'latin1', (None, b'a')): ('latin1', 4, 'a'),
+            (None, 'latin1', (None, 'ä'.encode())): (
                 'latin1',
                 4,
                 '\xc3\xa4',
             ),  # read as latin1!
             # ===== 5. default WINS which in this case is None! =====
-            (None, None, (None, ''.encode())): ('utf-8', 5, ''),
-            (None, None, (None, '123'.encode())): ('utf-8', 5, '123'),
-            (None, None, (None, 'a'.encode('ascii'))): ('utf-8', 5, 'a'),
-            (None, None, (None, 'ä'.encode('utf-8'))): (
+            (None, None, (None, b'')): ('utf-8', 5, ''),
+            (None, None, (None, b'123')): ('utf-8', 5, '123'),
+            (None, None, (None, b'a')): ('utf-8', 5, 'a'),
+            (None, None, (None, 'ä'.encode())): (
                 'utf-8',
                 5,
                 'ä',
@@ -369,149 +348,145 @@ class _readUrl_TestCase(basetest.BaseTestCase):
             ),
         }
         for (override, parent, r), exp in list(tests.items()):
-            self.assertEqual(
+            assert (
                 _readUrl(
                     url,
                     overrideEncoding=override,
                     parentEncoding=parent,
                     fetcher=make_fetcher(r),
-                ),
-                exp,
+                )
+                == exp
             )
 
     def test_defaultFetcher(self):  # noqa: C901
         """util._defaultFetcher"""
-        if mock:
 
-            class Response(object):
-                """urllib2.Reponse mock"""
+        class Response:
+            """urllib2.Reponse mock"""
 
-                def __init__(
-                    self, url, contenttype, content, exception=None, args=None
-                ):
-                    self.url = url
+            def __init__(self, url, contenttype, content, exception=None, args=None):
+                self.url = url
 
-                    mt, params = cgi.parse_header(contenttype)
-                    self.mimetype = mt
-                    self.charset = params.get('charset', None)
+                m = Message()
+                m['content-type'] = contenttype
 
-                    self.text = content
+                self.mimetype = m.get_content_type()
+                self.charset = m.get_param('charset', None)
 
-                    self.exception = exception
-                    self.args = args
+                self.text = content
 
-                def geturl(self):
-                    return self.url
+                self.exception = exception
+                self.args = args
 
-                def info(self):
-                    mimetype, charset = self.mimetype, self.charset
+            def geturl(self):
+                return self.url
 
-                    class Info(object):
+            def info(self):
+                mimetype, charset = self.mimetype, self.charset
 
-                        # py2x
-                        def gettype(self):
-                            return mimetype
+                class Info:
+                    # py2x
+                    def gettype(self):
+                        return mimetype
 
-                        def getparam(self, name=None):
-                            return charset
+                    def getparam(self, name=None):
+                        return charset
 
-                        # py 3x
-                        get_content_type = gettype
-                        get_content_charset = getparam  # here always charset!
+                    # py 3x
+                    get_content_type = gettype
+                    get_content_charset = getparam  # here always charset!
 
-                    return Info()
+                return Info()
 
-                def read(self):
-                    # returns fake text or raises fake exception
-                    if not self.exception:
-                        return self.text
-                    else:
-                        raise self.exception(*self.args)
+            def read(self):
+                # returns fake text or raises fake exception
+                if not self.exception:
+                    return self.text
+                else:
+                    raise self.exception(*self.args)
 
-            def urlopen(url, contenttype=None, content=None, exception=None, args=None):
-                # return an mock which returns parameterized Response
-                def x(*ignored):
-                    if exception:
-                        raise exception(*args)
-                    else:
-                        return Response(
-                            url, contenttype, content, exception=exception, args=args
-                        )
+        def urlopen(url, contenttype=None, content=None, exception=None, args=None):
+            # return an mock which returns parameterized Response
+            def x(*ignored):
+                if exception:
+                    raise exception(*args)
+                else:
+                    return Response(
+                        url, contenttype, content, exception=exception, args=args
+                    )
 
-                return x
+            return x
 
-            urlopenpatch = 'urllib.request.urlopen'
+        urlopenpatch = 'urllib.request.urlopen'
 
-            # positive tests
-            tests = {
-                # content-type, contentstr: encoding, contentstr
-                ('text/css', '€'.encode('utf-8')): (None, '€'.encode('utf-8')),
-                ('text/css;charset=utf-8', '€'.encode('utf-8')): (
-                    'utf-8',
-                    '€'.encode('utf-8'),
-                ),
-                ('text/css;charset=ascii', 'a'): ('ascii', 'a'),
-            }
-            url = 'http://example.com/test.css'
-            for (contenttype, content), exp in list(tests.items()):
+        # positive tests
+        tests = {
+            # content-type, contentstr: encoding, contentstr
+            ('text/css', '€'.encode()): (None, '€'.encode()),
+            ('text/css;charset=utf-8', '€'.encode()): (
+                'utf-8',
+                '€'.encode(),
+            ),
+            ('text/css;charset=ascii', 'a'): ('ascii', 'a'),
+        }
+        url = 'http://example.com/test.css'
+        for (contenttype, content), exp in list(tests.items()):
 
-                @mock.patch(urlopenpatch, new=urlopen(url, contenttype, content))
-                def do(url):
-                    return _defaultFetcher(url)
-
-                self.assertEqual(exp, do(url))
-
-            # wrong mimetype
-            @mock.patch(urlopenpatch, new=urlopen(url, 'text/html', 'a'))
+            @mock.patch(urlopenpatch, new=urlopen(url, contenttype, content))
             def do(url):
                 return _defaultFetcher(url)
 
-            self.assertRaises(ValueError, do, url)
+            assert exp == do(url)
 
-            # calling url results in fake exception
+        # wrong mimetype
+        @mock.patch(urlopenpatch, new=urlopen(url, 'text/html', 'a'))
+        def do(url):
+            return _defaultFetcher(url)
 
-            # py2 ~= py3 raises error earlier than urlopen!
-            tests = {
-                '1': (ValueError, ['invalid value for url']),
-                # _readUrl('mailto:a.css')
-                'mailto:e4': (urllib.error.URLError, ['urlerror']),
-                # cannot resolve x, IOError
-                'http://x': (urllib.error.URLError, ['ioerror']),
-            }
-            for url, (exception, args) in list(tests.items()):
+        with pytest.raises(ValueError):
+            do(url)
 
-                @mock.patch(
-                    urlopenpatch, new=urlopen(url, exception=exception, args=args)
-                )
-                def do(url):
-                    return _defaultFetcher(url)
+        # calling url results in fake exception
 
-                self.assertRaises(exception, do, url)
+        # py2 ~= py3 raises error earlier than urlopen!
+        tests = {
+            '1': (ValueError, ['invalid value for url']),
+            # _readUrl('mailto:a.css')
+            'mailto:e4': (urllib.error.URLError, ['urlerror']),
+            # cannot resolve x, IOError
+            'http://x': (urllib.error.URLError, ['ioerror']),
+        }
+        for url, (exception, args) in list(tests.items()):
 
-            urlrequestpatch = 'urllib.request.Request'
-            tests = {
-                # _readUrl('http://cthedot.de/__UNKNOWN__.css')
-                'e2': (urllib.error.HTTPError, ['u', 500, 'server error', {}, None]),
-                'e3': (urllib.error.HTTPError, ['u', 404, 'not found', {}, None]),
-            }
-            for url, (exception, args) in list(tests.items()):
+            @mock.patch(urlopenpatch, new=urlopen(url, exception=exception, args=args))
+            def do(url):
+                return _defaultFetcher(url)
 
-                @mock.patch(
-                    urlrequestpatch, new=urlopen(url, exception=exception, args=args)
-                )
-                def do(url):
-                    return _defaultFetcher(url)
+            with pytest.raises(exception):
+                do(url)
 
-                self.assertRaises(exception, do, url)
+        urlrequestpatch = 'urllib.request.Request'
+        tests = {
+            # _readUrl('http://cthedot.de/__UNKNOWN__.css')
+            'e2': (urllib.error.HTTPError, ['u', 500, 'server error', {}, None]),
+            'e3': (urllib.error.HTTPError, ['u', 404, 'not found', {}, None]),
+        }
+        for url, (exception, args) in list(tests.items()):
 
-        else:
-            self.assertEqual(False, 'Mock needed for this test')
+            @mock.patch(
+                urlrequestpatch, new=urlopen(url, exception=exception, args=args)
+            )
+            def do(url):
+                return _defaultFetcher(url)
+
+            with pytest.raises(exception):
+                do(url)
 
 
-class TestLazyRegex(basetest.BaseTestCase):
+class TestLazyRegex:
     """Tests for cssutils.util.LazyRegex."""
 
-    def setUp(self):
+    def setup_method(self):
         self.lazyre = LazyRegex('f.o')
 
     def test_public_interface(self):
@@ -529,82 +504,74 @@ class TestLazyRegex(basetest.BaseTestCase):
             'groupindex',
         ]
         for method in methods:
-            self.assertTrue(
-                hasattr(self.lazyre, method), 'expected %r public attribute' % method
-            )
+            assert hasattr(self.lazyre, method), 'expected %r public attribute' % method
 
     def test_ensure(self):
-        self.assertIsNone(self.lazyre.matcher)
+        assert self.lazyre.matcher is None
         self.lazyre.ensure()
-        self.assertIsNotNone(self.lazyre.matcher)
+        assert self.lazyre.matcher is not None
 
     def test_calling(self):
-        self.assertIsNone(self.lazyre('bar'))
+        assert self.lazyre('bar') is None
         match = self.lazyre('foobar')
-        self.assertEqual(match.group(), 'foo')
+        assert match.group() == 'foo'
 
     def test_matching(self):
-        self.assertIsNone(self.lazyre.match('bar'))
+        assert self.lazyre.match('bar') is None
         match = self.lazyre.match('foobar')
-        self.assertEqual(match.group(), 'foo')
+        assert match.group() == 'foo'
 
     def test_matching_with_position_parameters(self):
-        self.assertIsNone(self.lazyre.match('foo', 1))
-        self.assertIsNone(self.lazyre.match('foo', 0, 2))
+        assert self.lazyre.match('foo', 1) is None
+        assert self.lazyre.match('foo', 0, 2) is None
 
     def test_searching(self):
-        self.assertIsNone(self.lazyre.search('rafuubar'))
+        assert self.lazyre.search('rafuubar') is None
         match = self.lazyre.search('rafoobar')
-        self.assertEqual(match.group(), 'foo')
+        assert match.group() == 'foo'
 
     def test_searching_with_position_parameters(self):
-        self.assertIsNone(self.lazyre.search('rafoobar', 3))
-        self.assertIsNone(self.lazyre.search('rafoobar', 0, 4))
+        assert self.lazyre.search('rafoobar', 3) is None
+        assert self.lazyre.search('rafoobar', 0, 4) is None
         match = self.lazyre.search('rafoofuobar', 4)
-        self.assertEqual(match.group(), 'fuo')
+        assert match.group() == 'fuo'
 
     def test_split(self):
-        self.assertEqual(self.lazyre.split('rafoobarfoobaz'), ['ra', 'bar', 'baz'])
-        self.assertEqual(self.lazyre.split('rafoobarfoobaz', 1), ['ra', 'barfoobaz'])
+        assert self.lazyre.split('rafoobarfoobaz') == ['ra', 'bar', 'baz']
+        assert self.lazyre.split('rafoobarfoobaz', 1) == ['ra', 'barfoobaz']
 
     def test_findall(self):
-        self.assertEqual(self.lazyre.findall('rafoobarfuobaz'), ['foo', 'fuo'])
+        assert self.lazyre.findall('rafoobarfuobaz') == ['foo', 'fuo']
 
     def test_finditer(self):
         result = self.lazyre.finditer('rafoobarfuobaz')
-        self.assertEqual([m.group() for m in result], ['foo', 'fuo'])
+        assert [m.group() for m in result] == ['foo', 'fuo']
 
     def test_sub(self):
-        self.assertEqual(self.lazyre.sub('bar', 'foofoo'), 'barbar')
-        self.assertEqual(self.lazyre.sub(lambda x: 'baz', 'foofoo'), 'bazbaz')
+        assert self.lazyre.sub('bar', 'foofoo') == 'barbar'
+        assert self.lazyre.sub(lambda x: 'baz', 'foofoo') == 'bazbaz'
 
     def test_subn(self):
         subbed = self.lazyre.subn('bar', 'foofoo')
-        self.assertEqual(subbed, ('barbar', 2))
+        assert subbed == ('barbar', 2)
         subbed = self.lazyre.subn(lambda x: 'baz', 'foofoo')
-        self.assertEqual(subbed, ('bazbaz', 2))
+        assert subbed == ('bazbaz', 2)
 
     def test_groups(self):
         lazyre = LazyRegex('(.)(.)')
-        self.assertIsNone(lazyre.groups)
+        assert lazyre.groups is None
         lazyre.ensure()
-        self.assertEqual(lazyre.groups, 2)
+        assert lazyre.groups == 2
 
     def test_groupindex(self):
         lazyre = LazyRegex('(?P<foo>.)')
-        self.assertIsNone(lazyre.groupindex)
+        assert lazyre.groupindex is None
         lazyre.ensure()
-        self.assertEqual(lazyre.groupindex, {'foo': 1})
+        assert lazyre.groupindex == {'foo': 1}
 
     def test_flags(self):
         self.lazyre.ensure()
-        self.assertEqual(self.lazyre.flags, re.compile('.').flags)
+        assert self.lazyre.flags == re.compile('.').flags
 
     def test_pattern(self):
-        self.assertEqual(self.lazyre.pattern, 'f.o')
-
-
-if __name__ == '__main__':
-    import unittest
-
-    unittest.main()
+        assert self.lazyre.pattern == 'f.o'
