@@ -39,6 +39,7 @@ TODO
     - parse @charset of HTML elements?
     - check for more texttypes if only text given
 """
+
 __all__ = [
     'buildlog',
     'encodingByMediaType',
@@ -50,9 +51,9 @@ __all__ = [
     'EncodingInfo',
 ]
 
+from email.message import Message
 import html.parser
 import io
-import cgi
 import re
 import sys
 import urllib.request
@@ -129,13 +130,7 @@ class EncodingInfo:
         """Initialize all possible properties to ``None``, see class
         description
         """
-        self.encoding = (
-            self.mismatch
-        ) = (
-            self.logtext
-        ) = (
-            self.http_encoding
-        ) = (
+        self.encoding = self.mismatch = self.logtext = self.http_encoding = (
             self.http_media_type
         ) = self.meta_encoding = self.meta_media_type = self.xml_encoding = None
 
@@ -315,8 +310,11 @@ def getMetaInfo(text, log=None):
         pass
 
     if p.content_type:
-        media_type, params = cgi.parse_header(p.content_type)
-        encoding = params.get('charset')  # defaults to None
+        m = Message()
+        m['content-type'] = p.content_type
+
+        media_type = m.get_content_type()
+        encoding = m.get_param('charset')  # defaults to None
         if encoding:
             encoding = encoding.lower()
         if log:
@@ -646,7 +644,7 @@ def getEncodingInfo(response=None, text='', log=None, url=None):  # noqa: C901
         and encinfo.http_encoding != encinfo.xml_encoding
     ):
         encinfo.mismatch = True
-        log.warn(
+        log.warning(
             '"%s" (HTTP) != "%s" (XML) encoding mismatch'
             % (encinfo.http_encoding, encinfo.xml_encoding)
         )
